@@ -4,11 +4,14 @@ from itertools import product
 import mahotas as mt
 import numpy as np
 from scipy import linalg
-from skimage.feature.texture import greycomatrix
+from skimage.feature.texture import graycomatrix
 from skimage.util.shape import view_as_windows
 from enum import Enum, IntEnum
 
+
 logger = logging.getLogger('collageradiomics')
+logger.info('Logging set up.')
+
 
 def _svd_dominant_angles(dx, dy, dz, svd_radius):
     """Calculate a new numpy image containing the dominant angles for each voxel.
@@ -427,7 +430,7 @@ class Collage:
         cropped_img_array = img_array[min_y:max_y, min_x:max_x]
 
         # co-occurence matrix of all 8 directions and sum them
-        cooccurence_matrix = greycomatrix(cropped_img_array, [1], self.cooccurence_angles, levels=self.num_unique_angles)
+        cooccurence_matrix = graycomatrix(cropped_img_array, [1], self.cooccurence_angles, levels=self.num_unique_angles)
         cooccurence_matrix = np.sum(cooccurence_matrix, axis=3)
         cooccurence_matrix = cooccurence_matrix[:, :, 0]
 
@@ -455,7 +458,7 @@ class Collage:
         logger.debug(f'Rescaling dominant angles to {num_unique_angles} unique values.')
         dominant_angles_max = dominant_angles.max()
         dominant_angles_min = dominant_angles.min()
-        dominant_angles_binned = (dominant_angles - dominant_angles_min) / (dominant_angles_max - dominant_angles_min) * (num_unique_angles - 1)
+        dominant_angles_binned = (dominant_angles - dominant_angles_min) / (dominant_angles_max - dominant_angles_min + np.finfo(float).eps) * (num_unique_angles - 1)
         dominant_angles_binned = np.round(dominant_angles_binned).astype(int)
         logger.debug(f'Rescaling dominant angles done.')
 
